@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 
 import logging
-from Queue import Queue, LifoQueue
-from collections import defaultdict
+#from Queue import Queue, LifoQueue
+#from collections import defaultdict
 
 import tornado.web
 from tornado.httpclient import AsyncHTTPClient
@@ -15,7 +15,7 @@ from cyclops.handlers.healthcheck import HealthCheckHandler
 from cyclops.tasks import ProjectsUpdateTask, SendToSentryTask
 
 
-def get_cache(module_name):
+def get_class(module_name):
     if '.' not in module_name:
         return __import__(module_name)
 
@@ -48,9 +48,12 @@ def configure_app(self, config=None, log_level='INFO', debug=False, main_loop=No
         password=self.config.MYSQL_PASS
     )
 
-    cache_class = get_cache(self.config.CACHE_IMPLEMENTATION_CLASS)
+    cache_class = get_class(self.config.CACHE_IMPLEMENTATION_CLASS)
     self.cache = cache_class(self)
 
+    storage_class = get_class(self.config.STORAGE)
+    self.storage = storage_class(self)
+
     options = {}
 
     self.project_keys = {}
@@ -58,10 +61,10 @@ def configure_app(self, config=None, log_level='INFO', debug=False, main_loop=No
     self.processed_items = 0
     self.ignored_items = 0
 
-    if self.config.PROCESS_NEWER_MESSAGES_FIRST:
-        self.items_to_process = defaultdict(LifoQueue)
-    else:
-        self.items_to_process = defaultdict(Queue)
+    #if self.config.PROCESS_NEWER_MESSAGES_FIRST:
+        #self.items_to_process = defaultdict(LifoQueue)
+    #else:
+        #self.items_to_process = defaultdict(Queue)
 
     self.last_requests = []
     self.average_request_time = None
